==> flowable-idm-engine-6.1.0-sources.jar: org/flowable/idm/engine/impl/cmd/CheckPassword.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.idm.engine.impl.cmd;

import java.io.Serializable;

import org.flowable.idm.api.PasswordEncoder;
import org.flowable.idm.api.PasswordSalt;
import org.flowable.idm.engine.impl.interceptor.Command;
import org.flowable.idm.engine.impl.interceptor.CommandContext;

/**
 * @author Tom Baeyens
 */
public class CheckPassword implements Command<Boolean>, Serializable {

    private static final long serialVersionUID = 1L;

    protected String userId;
    protected String password;

    public CheckPassword(String userId, String password) {
        this.userId = userId;
        this.password = password;
    }

    public Boolean execute(CommandContext commandContext) {
        PasswordEncoder passwordEncoder = commandContext.getIdmEngineConfiguration().getPasswordEncoder();
        PasswordSalt passwordSalt = commandContext.getIdmEngineConfiguration().getPasswordSalt();
        
        return commandContext.getUserEntityManager().checkPassword(userId, password, passwordEncoder, passwordSalt);
    }

}

==> flowable-idm-engine-6.3.0-sources.jar: org/flowable/idm/engine/impl/cmd/CheckPassword.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.idm.engine.impl.cmd;

import java.io.Serializable;

import org.flowable.engine.common.impl.interceptor.Command;
import org.flowable.engine.common.impl.interceptor.CommandContext;
import org.flowable.idm.api.PasswordEncoder;
import org.flowable.idm.api.PasswordSalt;
import org.flowable.idm.engine.impl.util.CommandContextUtil;

/**
 * @author Tom Baeyens
 */
public class CheckPassword implements Command<Boolean>, Serializable {

    private static final long serialVersionUID = 1L;

    protected String userId;
    protected String password;

    public CheckPassword(String userId, String password) {
        this.userId = userId;
        this.password = password;
    }

    @Override
    public Boolean execute(CommandContext commandContext) {
        PasswordEncoder passwordEncoder = CommandContextUtil.getIdmEngineConfiguration().getPasswordEncoder();
        PasswordSalt passwordSalt = CommandContextUtil.getIdmEngineConfiguration().getPasswordSalt();
        
        return CommandContextUtil.getUserEntityManager(commandContext).checkPassword(userId, password, passwordEncoder, passwordSalt);
    }

}
